]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
Add sr_ prefix to 'struct samplerates'.
[libsigrok.git] / sigrok.h
index 9518041ce32fd0bce7d05a12050fd52b5d4e04b0..7d19725fd238ce49775440a93ec2266886a85906 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -299,7 +299,7 @@ enum {
        SR_DI_INSTANCE,
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
/* Samplerates supported by this device, (struct samplerates) */
        SR_DI_SAMPLERATES,
        /* Types of trigger supported, out of "01crf" (char *) */
        SR_DI_TRIGGER_TYPES,
@@ -314,7 +314,7 @@ enum {
  * granularity, or is limited to a set of defined samplerates. Use either
  * step or list, but not both.
  */
-struct samplerates {
+struct sr_samplerates {
        uint64_t low;
        uint64_t high;
        uint64_t step;
@@ -340,7 +340,7 @@ struct sr_device_plugin {
        void (*stop_acquisition) (int device_index, gpointer session_device_id);
 };
 
-struct session {
+struct sr_session {
        /* List of struct sr_device* */
        GSList *devices;
        /* List of struct analyzer* */
@@ -299,7 +299,7 @@ enum {
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
-       /* Samplerates supported by this device, (struct samplerates) */
+       /* Samplerates supported by this device, (struct sr_samplerates) */
        SR_DI_SAMPLERATES,
        /* Types of trigger supported, out of "01crf" (char *) */